package com.chelvc.cloud.maintain.controller;
import com.chelvc.cloud.vehicle.api.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.api.param.MerchantPagingParam;
import com.chelvc.cloud.vehicle.api.service.MerchantService;
import com.chelvc.framework.base.annotation.UnifiedResponseBody;
import com.chelvc.framework.base.model.Pagination;
import com.chelvc.framework.base.util.ErrorUtils;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import javax.validation.Valid;
import javax.validation.constraints.Min;
/**
 * 商家接口
 *
 * @author liude
 * @date 2023/7/20
 */
@Validated
@RestController
@UnifiedResponseBody
public class MerchantController {
    @DubboReference
    private MerchantService merchantService;

    /**
     * 获取商家信息
     *
     * @param id 商家主键
     * @return 商家信息
     */
    @GetMapping("/merchant/{id}")
    public MerchantDTO getRole(@PathVariable("id") @Min(value = 1, message = "商家主键不能小于1") Long id) {
        MerchantDTO merchant = this.merchantService.getMerchant(id);
        ErrorUtils.requireResource(merchant, "商家不存在");
        return merchant;
    }
    /**
     * 查询商家分页
     *
     * @param param 查询参数
     * @return 商家分页信息
     */
    @GetMapping("/merchant/paging")
    public Pagination<MerchantDTO> getMerchantPaging(@Valid MerchantPagingParam param) {
        return this.merchantService.getMerchantPaging(param);
    }
}
